@@ -1,9 +1,9 @@
 package Perinci::Sub::To::Text;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-23'; # DATE
+our $DATE = '2021-05-24'; # DATE
 our $DIST = 'Perinci-To-Doc'; # DIST
-our $VERSION = '0.876'; # VERSION
+our $VERSION = '0.877'; # VERSION
 
 use 5.010001;
 use Log::ger;
@@ -79,12 +79,12 @@ sub after_gen_doc {
     $self->add_doc_lines(__(
 'Returns an enveloped result (an array).
 
-First element ($status_code) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or "OK" if status is
-200. Third element ($payload) is optional, the actual result. Fourth
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
 element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information.'))
+that contains extra information, much like how HTTP response headers provide additional metadata.'))
         unless $orig_result_naked;
     $self->add_doc_lines($dres->{res_summary} . ($dres->{res_schema} ? " ($dres->{res_schema}[0])" : "")) if $dres->{res_summary};
 
@@ -108,7 +108,7 @@ Perinci::Sub::To::Text - Generate text documentation from Rinci function metadat
 
 =head1 VERSION
 
-This document describes version 0.876 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-05-23.
+This document describes version 0.877 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2021-05-24.
 
 =head1 SYNOPSIS
 
